@@ -290,8 +290,10 @@ module QuickML
     end
 
     def plain_text_body? (mail)
-      mail["Content-Type"] == "" or
-	%r!\btext/plain\b!i =~ mail["Content-Type"] #/
+      (mail["Content-Type"] == "" or 
+       %r!\btext/plain\b!i =~ mail["Content-Type"]) and
+        (mail["Content-Transfer-Encoding"] == "" or
+         /^[78]bit$/i =~ mail["Content-Transfer-Encoding"])
     end
 
     def rewrite_body (mail)
@@ -347,7 +349,7 @@ module QuickML
       [ ["Precedence",   "bulk"],
         ["X-ML-Address", @address],
 	["X-ML-Name",	 @name],
-	["X-ML-Info",	 "http://QuickML.COM/"],
+	["X-ML-Info",	 @config.info_url],
 	["X-QuickML",	 "true"]]
     end
 
@@ -819,7 +821,7 @@ module QuickML
       body << generate_footer
       Mail.send_mail(@config.smtp_host, @config.smtp_port, @logger,
 		     :mail_from => '', 
-		     :recipient => address,
+		     :recipient => @mail.from,
 		     :header => header,
 		     :body => body)
       @logger.log "[#{ml.name}]: Too Many Members: #{address}"
