@@ -72,19 +72,6 @@ class File
       exit(1)
     end
   end
-
-  # To discard the method defined in ftools.rb
-  class << self; remove_method :safe_unlink;  end
-  def self.safe_unlink (filename)
-    begin
-      File.unlink(filename)
-      if @@backup_dir
-	backup_filename = File.join(@@backup_dir, filename)
-	File.unlink(backup_filename)
-      end
-    rescue
-    end
-  end
 end
 
 class Integer
